==> form_helper_widget-8.x-0.1.tar.gz: form_helper_widget/src/Plugin/Derivative/FormHelperWidgetLocalAction.php <==
<?php

namespace Drupal\form_helper_widget\Plugin\Derivative;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\Routing\RouteProviderInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;

/**
 * Class FormHelperWidgetLocalAction
 *
 * @package Drupal\form_helper_widget\Plugin\Derivative
 */
class FormHelperWidgetLocalAction extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;


  protected $exceptions = ['paragraph', 'paragraphs_type'];
  
  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\RouteProviderInterface
   */
  protected $routeProvider;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a FieldUiLocalAction object.
   *
   * @param \Drupal\Core\Routing\RouteProviderInterface $route_provider
   *   The route provider to load routes by name.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(RouteProviderInterface $route_provider, EntityTypeManagerInterface $entity_type_manager) {
    $this->routeProvider = $route_provider;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('router.route_provider'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $this->derivatives = array();

    $definitions = array_diff_key($this->entityTypeManager->getDefinitions(), array_flip($this->exceptions));
    foreach ($definitions as $entity_type_id => $entity_type) {
      if ($entity_type->get('field_ui_base_route')) {
        $default_options = [
          'title' => $this->t('Add helper'),
        ];

        $this->derivatives['form_helper_widget_add_' . $entity_type_id . '_form_display'] = [
            'route_name' => "field_ui.form_helper_widget_add_$entity_type_id.form_display",
            'appears_on' => [
              "entity.entity_form_display.{$entity_type_id}.default",
            ],
          ] + $default_options;
      }
    }

    foreach ($this->derivatives as &$entry) {
      $entry += $base_plugin_definition;
    }

    return $this->derivatives;
  }

}

==> form_helper_widget-8.x-0.3.tar.gz: form_helper_widget/src/Plugin/Derivative/FormHelperWidgetLocalAction.php <==
<?php

namespace Drupal\form_helper_widget\Plugin\Derivative;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\Routing\RouteProviderInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;

/**
 * Class FormHelperWidgetLocalAction.
 *
 * @package Drupal\form_helper_widget\Plugin\Derivative
 */
class FormHelperWidgetLocalAction extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * Entity exception list.
   *
   * @var array
   */
  protected $exceptions = [];

  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\RouteProviderInterface
   */
  protected $routeProvider;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a FieldUiLocalAction object.
   *
   * @param \Drupal\Core\Routing\RouteProviderInterface $route_provider
   *   The route provider to load routes by name.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(RouteProviderInterface $route_provider, EntityTypeManagerInterface $entity_type_manager) {
    $this->routeProvider = $route_provider;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('router.route_provider'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $this->derivatives = [];

    $definitions = array_diff_key($this->entityTypeManager->getDefinitions(), array_flip($this->exceptions));
    foreach ($definitions as $entity_type_id => $entity_type) {
      if ($entity_type->get('field_ui_base_route')) {
        $default_options = [
          'title' => $this->t('Add helper'),
        ];

        $this->derivatives['form_helper_widget_add_' . $entity_type_id . '_form_display'] = [
          'route_name' => 'field_ui.form_helper_widget_add_' . $entity_type_id . '.form_display',
          'appears_on' => [
            'entity.entity_form_display.' . $entity_type_id . '.default',
          ],
        ] + $default_options;
      }
    }

    foreach ($this->derivatives as &$entry) {
      $entry += $base_plugin_definition;
    }

    return $this->derivatives;
  }

}
